@@ -404,7 +404,7 @@ main(int argc, char *argv[])
 	struct block *b;
 	struct variable *c, *v;
 	DIR *bdir, *idir;
-	struct dirent be, ie, *br, *ir;
+	struct dirent *ir, *br;
 	char file[PATH_MAX + 1], contentfile[PATH_MAX + 1], path[PATH_MAX + 1];
 	char outputfile[PATH_MAX + 1], *p, *filename;
 	size_t i, j, k, templateslen;
@@ -421,9 +421,9 @@ main(int argc, char *argv[])
 		if (argi + 1 >= argc)
 			usage(argv[0]);
 		switch (argv[argi][1]) {
-		case 'c': configfile = argv[argi + 1]; break;
-		case 'o': outputdir = argv[argi + 1]; break;
-		case 't': templatedir = argv[argi + 1]; break;
+		case 'c': configfile = argv[++argi]; break;
+		case 'o': outputdir = argv[++argi]; break;
+		case 't': templatedir = argv[++argi]; break;
 		default: usage(argv[0]); break;
 		}
 	}
@@ -438,7 +438,7 @@ main(int argc, char *argv[])
 		exit(1);
 	}
 
-	while (!readdir_r(bdir, &be, &br) && br) {
+	while ((br = readdir(bdir))) {
 		if (br->d_name[0] == '.')
 			continue;
 
@@ -466,7 +466,7 @@ main(int argc, char *argv[])
 		memset(t, 0, sizeof(struct template));
 		t->name = estrdup(br->d_name);
 
-		while (!readdir_r(idir, &ie, &ir) && ir) {
+		while ((ir = readdir(idir))) {
 			if (!strncmp(ir->d_name, "header.", sizeof("header.") - 1))
 				b = &(t->blocks[BlockHeader]);
 			else if (!strncmp(ir->d_name, "item.", sizeof("item.") - 1))
@@ -483,8 +483,8 @@ main(int argc, char *argv[])
 				        path, ir->d_name);
 				exit(1);
 			}
-			b->data = readfile(file);
 			b->name = estrdup(file);
+			b->data = readfile(file);
 		}
 		closedir(idir);
 	}
@@ -564,8 +564,9 @@ main(int argc, char *argv[])
 				fclose(templates[j].fp);
 			} else {
 				b = &templates[j].blocks[BlockItem];
-				writepage(templates[j].fp, b->name, argv[i], c,
-				          b->data);
+				if (b->name)
+					writepage(templates[j].fp, b->name,
+					          argv[i], c, b->data);
 			}
 		}
 		freevars(c);
